@@ -103,6 +103,16 @@ typedef struct ParamMeta {
   };
 } ParamMeta;
 
+#define MOP_CLASS_RUN_HOOKS_NOARGS(classmeta, func)                                       \
+  {                                                                                       \
+    U32 hooki;                                                                            \
+    for(hooki = 0; classmeta->hooks && hooki < av_count(classmeta->hooks); hooki++) {     \
+      struct ClassHook *h = (struct ClassHook *)AvARRAY(classmeta->hooks)[hooki];         \
+      if(*h->funcs->func)                                                                 \
+        (*h->funcs->func)(aTHX_ classmeta, h->hookdata, h->funcdata);                     \
+    }                                                                                     \
+  }
+
 #define MOP_CLASS_RUN_HOOKS(classmeta, func, ...)                                         \
   {                                                                                       \
     U32 hooki;                                                                            \
