@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2022 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.75;
+package Object::Pad 0.76;
 
 use v5.14;
 use warnings;
@@ -635,11 +635,15 @@ would be dangerous to allow access to it while in this state. However, the
 C<__CLASS__> keyword is available, so initialiser expressions can make use of
 class-based dispatch to invoke class-level methods to help provide values.
 
-This feature should be considered B<experimental>, and will emit warnings to
-that effect. They can be silenced with
+This feature should be considered partly B<experimental> and may emit warnings
+to that effect. They can be silenced with
 
    use Object::Pad ':experimental(init_expr)';
 
+I<Since version 0.76> expressions that are purely compiletime constants
+(either as single scalars or entire lists of constants) are no longer
+considered experimental. They can be used without silencing the warning.
+
 Control flow that attempts to leave a field initialiser expression or block is
 not permitted. This includes any C<return> expression, any C<next/last/redo>
 outside of a loop, with a dynamically-calculated label expression, or with a
@@ -1274,8 +1278,7 @@ sub Object::Pad::UNIVERSAL::BUILDARGS
 sub Object::Pad::MOP::SlotAttr::register
 {
    shift; # $class
-   carp "Object::Pad::MOP::SlotAttr->register is now deprecated; use Object::Pad::MOP::FieldAttr->register instead";
-   return Object::Pad::MOP::FieldAttr->register( @_ );
+   croak "Object::Pad::MOP::SlotAttr->register is now removed; use Object::Pad::MOP::FieldAttr->register instead";
 }
 
 =head1 WITH OTHER MODULES
